#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenIdOrder(object):

    def __init__(self):
        self._order_id = None
        self._order_status = None
        self._refuse_reason = None

    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def refuse_reason(self):
        return self._refuse_reason

    @refuse_reason.setter
    def refuse_reason(self, value):
        self._refuse_reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.refuse_reason:
            if hasattr(self.refuse_reason, 'to_alipay_dict'):
                params['refuse_reason'] = self.refuse_reason.to_alipay_dict()
            else:
                params['refuse_reason'] = self.refuse_reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenIdOrder()
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'refuse_reason' in d:
            o.refuse_reason = d['refuse_reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RequestExtShopItem import RequestExtShopItem


class KoubeiRetailShopitemUploadModel(object):

    def __init__(self):
        self._shop_items = None

    @property
    def shop_items(self):
        return self._shop_items

    @shop_items.setter
    def shop_items(self, value):
        if isinstance(value, list):
            self._shop_items = list()
            for i in value:
                if isinstance(i, RequestExtShopItem):
                    self._shop_items.append(i)
                else:
                    self._shop_items.append(RequestExtShopItem.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.shop_items:
            if isinstance(self.shop_items, list):
                for i in range(0, len(self.shop_items)):
                    element = self.shop_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_items[i] = element.to_alipay_dict()
            if hasattr(self.shop_items, 'to_alipay_dict'):
                params['shop_items'] = self.shop_items.to_alipay_dict()
            else:
                params['shop_items'] = self.shop_items
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailShopitemUploadModel()
        if 'shop_items' in d:
            o.shop_items = d['shop_items']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankPaymentTradeNormalpayOrderCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankPaymentTradeNormalpayOrderCreateResponse, self).__init__()
        self._cashier_url = None
        self._order_no = None
        self._request_accept_time = None
        self._request_no = None
        self._retry = None

    @property
    def cashier_url(self):
        return self._cashier_url

    @cashier_url.setter
    def cashier_url(self, value):
        self._cashier_url = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def request_accept_time(self):
        return self._request_accept_time

    @request_accept_time.setter
    def request_accept_time(self, value):
        self._request_accept_time = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value

    def parse_response_content(self, response_content):
        response = super(MybankPaymentTradeNormalpayOrderCreateResponse, self).parse_response_content(response_content)
        if 'cashier_url' in response:
            self.cashier_url = response['cashier_url']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'request_accept_time' in response:
            self.request_accept_time = response['request_accept_time']
        if 'request_no' in response:
            self.request_no = response['request_no']
        if 'retry' in response:
            self.retry = response['retry']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AmountTypeSyncData(object):

    def __init__(self):
        self._discount_amount = None
        self._discount_desc = None
        self._has_alipay_trade = None
        self._task_amount = None
        self._task_desc = None
        self._trade_no = None

    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_desc(self):
        return self._discount_desc

    @discount_desc.setter
    def discount_desc(self, value):
        self._discount_desc = value
    @property
    def has_alipay_trade(self):
        return self._has_alipay_trade

    @has_alipay_trade.setter
    def has_alipay_trade(self, value):
        self._has_alipay_trade = value
    @property
    def task_amount(self):
        return self._task_amount

    @task_amount.setter
    def task_amount(self, value):
        self._task_amount = value
    @property
    def task_desc(self):
        return self._task_desc

    @task_desc.setter
    def task_desc(self, value):
        self._task_desc = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_desc:
            if hasattr(self.discount_desc, 'to_alipay_dict'):
                params['discount_desc'] = self.discount_desc.to_alipay_dict()
            else:
                params['discount_desc'] = self.discount_desc
        if self.has_alipay_trade:
            if hasattr(self.has_alipay_trade, 'to_alipay_dict'):
                params['has_alipay_trade'] = self.has_alipay_trade.to_alipay_dict()
            else:
                params['has_alipay_trade'] = self.has_alipay_trade
        if self.task_amount:
            if hasattr(self.task_amount, 'to_alipay_dict'):
                params['task_amount'] = self.task_amount.to_alipay_dict()
            else:
                params['task_amount'] = self.task_amount
        if self.task_desc:
            if hasattr(self.task_desc, 'to_alipay_dict'):
                params['task_desc'] = self.task_desc.to_alipay_dict()
            else:
                params['task_desc'] = self.task_desc
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AmountTypeSyncData()
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_desc' in d:
            o.discount_desc = d['discount_desc']
        if 'has_alipay_trade' in d:
            o.has_alipay_trade = d['has_alipay_trade']
        if 'task_amount' in d:
            o.task_amount = d['task_amount']
        if 'task_desc' in d:
            o.task_desc = d['task_desc']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EcoMockGroupInfo(object):

    def __init__(self):
        self._app_code = None
        self._description = None
        self._id = None
        self._mock_count = None
        self._name = None
        self._status = None

    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def mock_count(self):
        return self._mock_count

    @mock_count.setter
    def mock_count(self, value):
        self._mock_count = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.mock_count:
            if hasattr(self.mock_count, 'to_alipay_dict'):
                params['mock_count'] = self.mock_count.to_alipay_dict()
            else:
                params['mock_count'] = self.mock_count
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EcoMockGroupInfo()
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'description' in d:
            o.description = d['description']
        if 'id' in d:
            o.id = d['id']
        if 'mock_count' in d:
            o.mock_count = d['mock_count']
        if 'name' in d:
            o.name = d['name']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LegalRepresentativeInfo(object):

    def __init__(self):
        self._legal_representative_cert_indate = None
        self._legal_representative_cert_no = None
        self._legal_representative_cert_pic_back = None
        self._legal_representative_cert_pic_front = None
        self._legal_representative_cert_type = None
        self._legal_representative_name = None

    @property
    def legal_representative_cert_indate(self):
        return self._legal_representative_cert_indate

    @legal_representative_cert_indate.setter
    def legal_representative_cert_indate(self, value):
        self._legal_representative_cert_indate = value
    @property
    def legal_representative_cert_no(self):
        return self._legal_representative_cert_no

    @legal_representative_cert_no.setter
    def legal_representative_cert_no(self, value):
        self._legal_representative_cert_no = value
    @property
    def legal_representative_cert_pic_back(self):
        return self._legal_representative_cert_pic_back

    @legal_representative_cert_pic_back.setter
    def legal_representative_cert_pic_back(self, value):
        self._legal_representative_cert_pic_back = value
    @property
    def legal_representative_cert_pic_front(self):
        return self._legal_representative_cert_pic_front

    @legal_representative_cert_pic_front.setter
    def legal_representative_cert_pic_front(self, value):
        self._legal_representative_cert_pic_front = value
    @property
    def legal_representative_cert_type(self):
        return self._legal_representative_cert_type

    @legal_representative_cert_type.setter
    def legal_representative_cert_type(self, value):
        self._legal_representative_cert_type = value
    @property
    def legal_representative_name(self):
        return self._legal_representative_name

    @legal_representative_name.setter
    def legal_representative_name(self, value):
        self._legal_representative_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.legal_representative_cert_indate:
            if hasattr(self.legal_representative_cert_indate, 'to_alipay_dict'):
                params['legal_representative_cert_indate'] = self.legal_representative_cert_indate.to_alipay_dict()
            else:
                params['legal_representative_cert_indate'] = self.legal_representative_cert_indate
        if self.legal_representative_cert_no:
            if hasattr(self.legal_representative_cert_no, 'to_alipay_dict'):
                params['legal_representative_cert_no'] = self.legal_representative_cert_no.to_alipay_dict()
            else:
                params['legal_representative_cert_no'] = self.legal_representative_cert_no
        if self.legal_representative_cert_pic_back:
            if hasattr(self.legal_representative_cert_pic_back, 'to_alipay_dict'):
                params['legal_representative_cert_pic_back'] = self.legal_representative_cert_pic_back.to_alipay_dict()
            else:
                params['legal_representative_cert_pic_back'] = self.legal_representative_cert_pic_back
        if self.legal_representative_cert_pic_front:
            if hasattr(self.legal_representative_cert_pic_front, 'to_alipay_dict'):
                params['legal_representative_cert_pic_front'] = self.legal_representative_cert_pic_front.to_alipay_dict()
            else:
                params['legal_representative_cert_pic_front'] = self.legal_representative_cert_pic_front
        if self.legal_representative_cert_type:
            if hasattr(self.legal_representative_cert_type, 'to_alipay_dict'):
                params['legal_representative_cert_type'] = self.legal_representative_cert_type.to_alipay_dict()
            else:
                params['legal_representative_cert_type'] = self.legal_representative_cert_type
        if self.legal_representative_name:
            if hasattr(self.legal_representative_name, 'to_alipay_dict'):
                params['legal_representative_name'] = self.legal_representative_name.to_alipay_dict()
            else:
                params['legal_representative_name'] = self.legal_representative_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LegalRepresentativeInfo()
        if 'legal_representative_cert_indate' in d:
            o.legal_representative_cert_indate = d['legal_representative_cert_indate']
        if 'legal_representative_cert_no' in d:
            o.legal_representative_cert_no = d['legal_representative_cert_no']
        if 'legal_representative_cert_pic_back' in d:
            o.legal_representative_cert_pic_back = d['legal_representative_cert_pic_back']
        if 'legal_representative_cert_pic_front' in d:
            o.legal_representative_cert_pic_front = d['legal_representative_cert_pic_front']
        if 'legal_representative_cert_type' in d:
            o.legal_representative_cert_type = d['legal_representative_cert_type']
        if 'legal_representative_name' in d:
            o.legal_representative_name = d['legal_representative_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LinkMallCallBackInfo(object):

    def __init__(self):
        self._action = None
        self._bizid = None
        self._extinfo = None
        self._lmuserid = None
        self._promotionid = None
        self._promotioninstanceid = None
        self._taobaoid = None
        self._time_stamp = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def bizid(self):
        return self._bizid

    @bizid.setter
    def bizid(self, value):
        self._bizid = value
    @property
    def extinfo(self):
        return self._extinfo

    @extinfo.setter
    def extinfo(self, value):
        self._extinfo = value
    @property
    def lmuserid(self):
        return self._lmuserid

    @lmuserid.setter
    def lmuserid(self, value):
        self._lmuserid = value
    @property
    def promotionid(self):
        return self._promotionid

    @promotionid.setter
    def promotionid(self, value):
        self._promotionid = value
    @property
    def promotioninstanceid(self):
        return self._promotioninstanceid

    @promotioninstanceid.setter
    def promotioninstanceid(self, value):
        self._promotioninstanceid = value
    @property
    def taobaoid(self):
        return self._taobaoid

    @taobaoid.setter
    def taobaoid(self, value):
        self._taobaoid = value
    @property
    def time_stamp(self):
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, value):
        self._time_stamp = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.bizid:
            if hasattr(self.bizid, 'to_alipay_dict'):
                params['bizid'] = self.bizid.to_alipay_dict()
            else:
                params['bizid'] = self.bizid
        if self.extinfo:
            if hasattr(self.extinfo, 'to_alipay_dict'):
                params['extinfo'] = self.extinfo.to_alipay_dict()
            else:
                params['extinfo'] = self.extinfo
        if self.lmuserid:
            if hasattr(self.lmuserid, 'to_alipay_dict'):
                params['lmuserid'] = self.lmuserid.to_alipay_dict()
            else:
                params['lmuserid'] = self.lmuserid
        if self.promotionid:
            if hasattr(self.promotionid, 'to_alipay_dict'):
                params['promotionid'] = self.promotionid.to_alipay_dict()
            else:
                params['promotionid'] = self.promotionid
        if self.promotioninstanceid:
            if hasattr(self.promotioninstanceid, 'to_alipay_dict'):
                params['promotioninstanceid'] = self.promotioninstanceid.to_alipay_dict()
            else:
                params['promotioninstanceid'] = self.promotioninstanceid
        if self.taobaoid:
            if hasattr(self.taobaoid, 'to_alipay_dict'):
                params['taobaoid'] = self.taobaoid.to_alipay_dict()
            else:
                params['taobaoid'] = self.taobaoid
        if self.time_stamp:
            if hasattr(self.time_stamp, 'to_alipay_dict'):
                params['time_stamp'] = self.time_stamp.to_alipay_dict()
            else:
                params['time_stamp'] = self.time_stamp
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LinkMallCallBackInfo()
        if 'action' in d:
            o.action = d['action']
        if 'bizid' in d:
            o.bizid = d['bizid']
        if 'extinfo' in d:
            o.extinfo = d['extinfo']
        if 'lmuserid' in d:
            o.lmuserid = d['lmuserid']
        if 'promotionid' in d:
            o.promotionid = d['promotionid']
        if 'promotioninstanceid' in d:
            o.promotioninstanceid = d['promotioninstanceid']
        if 'taobaoid' in d:
            o.taobaoid = d['taobaoid']
        if 'time_stamp' in d:
            o.time_stamp = d['time_stamp']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CropsGrowthInfo(object):

    def __init__(self):
        self._actual_date = None
        self._addition_info = None
        self._crop_code = None
        self._general_area = None
        self._strength = None
        self._stronger_area = None
        self._strongest_area = None
        self._warn = None
        self._weaker_area = None
        self._weakest_area = None

    @property
    def actual_date(self):
        return self._actual_date

    @actual_date.setter
    def actual_date(self, value):
        self._actual_date = value
    @property
    def addition_info(self):
        return self._addition_info

    @addition_info.setter
    def addition_info(self, value):
        self._addition_info = value
    @property
    def crop_code(self):
        return self._crop_code

    @crop_code.setter
    def crop_code(self, value):
        self._crop_code = value
    @property
    def general_area(self):
        return self._general_area

    @general_area.setter
    def general_area(self, value):
        self._general_area = value
    @property
    def strength(self):
        return self._strength

    @strength.setter
    def strength(self, value):
        self._strength = value
    @property
    def stronger_area(self):
        return self._stronger_area

    @stronger_area.setter
    def stronger_area(self, value):
        self._stronger_area = value
    @property
    def strongest_area(self):
        return self._strongest_area

    @strongest_area.setter
    def strongest_area(self, value):
        self._strongest_area = value
    @property
    def warn(self):
        return self._warn

    @warn.setter
    def warn(self, value):
        self._warn = value
    @property
    def weaker_area(self):
        return self._weaker_area

    @weaker_area.setter
    def weaker_area(self, value):
        self._weaker_area = value
    @property
    def weakest_area(self):
        return self._weakest_area

    @weakest_area.setter
    def weakest_area(self, value):
        self._weakest_area = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_date:
            if hasattr(self.actual_date, 'to_alipay_dict'):
                params['actual_date'] = self.actual_date.to_alipay_dict()
            else:
                params['actual_date'] = self.actual_date
        if self.addition_info:
            if hasattr(self.addition_info, 'to_alipay_dict'):
                params['addition_info'] = self.addition_info.to_alipay_dict()
            else:
                params['addition_info'] = self.addition_info
        if self.crop_code:
            if hasattr(self.crop_code, 'to_alipay_dict'):
                params['crop_code'] = self.crop_code.to_alipay_dict()
            else:
                params['crop_code'] = self.crop_code
        if self.general_area:
            if hasattr(self.general_area, 'to_alipay_dict'):
                params['general_area'] = self.general_area.to_alipay_dict()
            else:
                params['general_area'] = self.general_area
        if self.strength:
            if hasattr(self.strength, 'to_alipay_dict'):
                params['strength'] = self.strength.to_alipay_dict()
            else:
                params['strength'] = self.strength
        if self.stronger_area:
            if hasattr(self.stronger_area, 'to_alipay_dict'):
                params['stronger_area'] = self.stronger_area.to_alipay_dict()
            else:
                params['stronger_area'] = self.stronger_area
        if self.strongest_area:
            if hasattr(self.strongest_area, 'to_alipay_dict'):
                params['strongest_area'] = self.strongest_area.to_alipay_dict()
            else:
                params['strongest_area'] = self.strongest_area
        if self.warn:
            if hasattr(self.warn, 'to_alipay_dict'):
                params['warn'] = self.warn.to_alipay_dict()
            else:
                params['warn'] = self.warn
        if self.weaker_area:
            if hasattr(self.weaker_area, 'to_alipay_dict'):
                params['weaker_area'] = self.weaker_area.to_alipay_dict()
            else:
                params['weaker_area'] = self.weaker_area
        if self.weakest_area:
            if hasattr(self.weakest_area, 'to_alipay_dict'):
                params['weakest_area'] = self.weakest_area.to_alipay_dict()
            else:
                params['weakest_area'] = self.weakest_area
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CropsGrowthInfo()
        if 'actual_date' in d:
            o.actual_date = d['actual_date']
        if 'addition_info' in d:
            o.addition_info = d['addition_info']
        if 'crop_code' in d:
            o.crop_code = d['crop_code']
        if 'general_area' in d:
            o.general_area = d['general_area']
        if 'strength' in d:
            o.strength = d['strength']
        if 'stronger_area' in d:
            o.stronger_area = d['stronger_area']
        if 'strongest_area' in d:
            o.strongest_area = d['strongest_area']
        if 'warn' in d:
            o.warn = d['warn']
        if 'weaker_area' in d:
            o.weaker_area = d['weaker_area']
        if 'weakest_area' in d:
            o.weakest_area = d['weakest_area']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiAuthAccumulationQueryModel(object):

    def __init__(self):
        self._agreement_no = None
        self._alipay_user_id = None
        self._open_id = None
        self._period = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiAuthAccumulationQueryModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'period' in d:
            o.period = d['period']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankPaymentTradeBankBranchQueryModel(object):

    def __init__(self):
        self._bank_name = None
        self._branch_bank_code = None
        self._district_code = None
        self._root_bank_code = None

    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def branch_bank_code(self):
        return self._branch_bank_code

    @branch_bank_code.setter
    def branch_bank_code(self, value):
        self._branch_bank_code = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def root_bank_code(self):
        return self._root_bank_code

    @root_bank_code.setter
    def root_bank_code(self, value):
        self._root_bank_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.branch_bank_code:
            if hasattr(self.branch_bank_code, 'to_alipay_dict'):
                params['branch_bank_code'] = self.branch_bank_code.to_alipay_dict()
            else:
                params['branch_bank_code'] = self.branch_bank_code
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.root_bank_code:
            if hasattr(self.root_bank_code, 'to_alipay_dict'):
                params['root_bank_code'] = self.root_bank_code.to_alipay_dict()
            else:
                params['root_bank_code'] = self.root_bank_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeBankBranchQueryModel()
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'branch_bank_code' in d:
            o.branch_bank_code = d['branch_bank_code']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'root_bank_code' in d:
            o.root_bank_code = d['root_bank_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItermInfo(object):

    def __init__(self):
        self._error_message = None
        self._is_for_sale = None
        self._item_code = None
        self._mark_price = None
        self._success = None
        self._supplier_price = None

    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def is_for_sale(self):
        return self._is_for_sale

    @is_for_sale.setter
    def is_for_sale(self, value):
        self._is_for_sale = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def mark_price(self):
        return self._mark_price

    @mark_price.setter
    def mark_price(self, value):
        self._mark_price = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def supplier_price(self):
        return self._supplier_price

    @supplier_price.setter
    def supplier_price(self, value):
        self._supplier_price = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_message:
            if hasattr(self.error_message, 'to_alipay_dict'):
                params['error_message'] = self.error_message.to_alipay_dict()
            else:
                params['error_message'] = self.error_message
        if self.is_for_sale:
            if hasattr(self.is_for_sale, 'to_alipay_dict'):
                params['is_for_sale'] = self.is_for_sale.to_alipay_dict()
            else:
                params['is_for_sale'] = self.is_for_sale
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.mark_price:
            if hasattr(self.mark_price, 'to_alipay_dict'):
                params['mark_price'] = self.mark_price.to_alipay_dict()
            else:
                params['mark_price'] = self.mark_price
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        if self.supplier_price:
            if hasattr(self.supplier_price, 'to_alipay_dict'):
                params['supplier_price'] = self.supplier_price.to_alipay_dict()
            else:
                params['supplier_price'] = self.supplier_price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItermInfo()
        if 'error_message' in d:
            o.error_message = d['error_message']
        if 'is_for_sale' in d:
            o.is_for_sale = d['is_for_sale']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'mark_price' in d:
            o.mark_price = d['mark_price']
        if 'success' in d:
            o.success = d['success']
        if 'supplier_price' in d:
            o.supplier_price = d['supplier_price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessDistrictInfo(object):

    def __init__(self):
        self._bindable = None
        self._business_district_id = None
        self._business_district_name = None
        self._unbindable_error_code = None
        self._unbindable_error_msg = None

    @property
    def bindable(self):
        return self._bindable

    @bindable.setter
    def bindable(self, value):
        self._bindable = value
    @property
    def business_district_id(self):
        return self._business_district_id

    @business_district_id.setter
    def business_district_id(self, value):
        self._business_district_id = value
    @property
    def business_district_name(self):
        return self._business_district_name

    @business_district_name.setter
    def business_district_name(self, value):
        self._business_district_name = value
    @property
    def unbindable_error_code(self):
        return self._unbindable_error_code

    @unbindable_error_code.setter
    def unbindable_error_code(self, value):
        self._unbindable_error_code = value
    @property
    def unbindable_error_msg(self):
        return self._unbindable_error_msg

    @unbindable_error_msg.setter
    def unbindable_error_msg(self, value):
        self._unbindable_error_msg = value


    def to_alipay_dict(self):
        params = dict()
        if self.bindable:
            if hasattr(self.bindable, 'to_alipay_dict'):
                params['bindable'] = self.bindable.to_alipay_dict()
            else:
                params['bindable'] = self.bindable
        if self.business_district_id:
            if hasattr(self.business_district_id, 'to_alipay_dict'):
                params['business_district_id'] = self.business_district_id.to_alipay_dict()
            else:
                params['business_district_id'] = self.business_district_id
        if self.business_district_name:
            if hasattr(self.business_district_name, 'to_alipay_dict'):
                params['business_district_name'] = self.business_district_name.to_alipay_dict()
            else:
                params['business_district_name'] = self.business_district_name
        if self.unbindable_error_code:
            if hasattr(self.unbindable_error_code, 'to_alipay_dict'):
                params['unbindable_error_code'] = self.unbindable_error_code.to_alipay_dict()
            else:
                params['unbindable_error_code'] = self.unbindable_error_code
        if self.unbindable_error_msg:
            if hasattr(self.unbindable_error_msg, 'to_alipay_dict'):
                params['unbindable_error_msg'] = self.unbindable_error_msg.to_alipay_dict()
            else:
                params['unbindable_error_msg'] = self.unbindable_error_msg
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessDistrictInfo()
        if 'bindable' in d:
            o.bindable = d['bindable']
        if 'business_district_id' in d:
            o.business_district_id = d['business_district_id']
        if 'business_district_name' in d:
            o.business_district_name = d['business_district_name']
        if 'unbindable_error_code' in d:
            o.unbindable_error_code = d['unbindable_error_code']
        if 'unbindable_error_msg' in d:
            o.unbindable_error_msg = d['unbindable_error_msg']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IotDeviceBindInfo(object):

    def __init__(self):
        self._app_type = None
        self._application_id = None
        self._biz_tid = None
        self._device_id_type = None
        self._device_sn = None
        self._equipment_type = None
        self._external_id = None
        self._external_id_secret = None
        self._external_shop_id = None
        self._merchant_id = None
        self._merchant_id_type = None
        self._mini_app_id = None
        self._shop_id = None
        self._source = None
        self._spi_app_id = None
        self._supplier_id = None
        self._terminal_bind_info = None

    @property
    def app_type(self):
        return self._app_type

    @app_type.setter
    def app_type(self, value):
        self._app_type = value
    @property
    def application_id(self):
        return self._application_id

    @application_id.setter
    def application_id(self, value):
        self._application_id = value
    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def device_id_type(self):
        return self._device_id_type

    @device_id_type.setter
    def device_id_type(self, value):
        self._device_id_type = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def equipment_type(self):
        return self._equipment_type

    @equipment_type.setter
    def equipment_type(self, value):
        self._equipment_type = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def external_id_secret(self):
        return self._external_id_secret

    @external_id_secret.setter
    def external_id_secret(self, value):
        self._external_id_secret = value
    @property
    def external_shop_id(self):
        return self._external_shop_id

    @external_shop_id.setter
    def external_shop_id(self, value):
        self._external_shop_id = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def merchant_id_type(self):
        return self._merchant_id_type

    @merchant_id_type.setter
    def merchant_id_type(self, value):
        self._merchant_id_type = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def spi_app_id(self):
        return self._spi_app_id

    @spi_app_id.setter
    def spi_app_id(self, value):
        self._spi_app_id = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value
    @property
    def terminal_bind_info(self):
        return self._terminal_bind_info

    @terminal_bind_info.setter
    def terminal_bind_info(self, value):
        self._terminal_bind_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_type:
            if hasattr(self.app_type, 'to_alipay_dict'):
                params['app_type'] = self.app_type.to_alipay_dict()
            else:
                params['app_type'] = self.app_type
        if self.application_id:
            if hasattr(self.application_id, 'to_alipay_dict'):
                params['application_id'] = self.application_id.to_alipay_dict()
            else:
                params['application_id'] = self.application_id
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.device_id_type:
            if hasattr(self.device_id_type, 'to_alipay_dict'):
                params['device_id_type'] = self.device_id_type.to_alipay_dict()
            else:
                params['device_id_type'] = self.device_id_type
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.equipment_type:
            if hasattr(self.equipment_type, 'to_alipay_dict'):
                params['equipment_type'] = self.equipment_type.to_alipay_dict()
            else:
                params['equipment_type'] = self.equipment_type
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.external_id_secret:
            if hasattr(self.external_id_secret, 'to_alipay_dict'):
                params['external_id_secret'] = self.external_id_secret.to_alipay_dict()
            else:
                params['external_id_secret'] = self.external_id_secret
        if self.external_shop_id:
            if hasattr(self.external_shop_id, 'to_alipay_dict'):
                params['external_shop_id'] = self.external_shop_id.to_alipay_dict()
            else:
                params['external_shop_id'] = self.external_shop_id
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.merchant_id_type:
            if hasattr(self.merchant_id_type, 'to_alipay_dict'):
                params['merchant_id_type'] = self.merchant_id_type.to_alipay_dict()
            else:
                params['merchant_id_type'] = self.merchant_id_type
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.spi_app_id:
            if hasattr(self.spi_app_id, 'to_alipay_dict'):
                params['spi_app_id'] = self.spi_app_id.to_alipay_dict()
            else:
                params['spi_app_id'] = self.spi_app_id
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        if self.terminal_bind_info:
            if hasattr(self.terminal_bind_info, 'to_alipay_dict'):
                params['terminal_bind_info'] = self.terminal_bind_info.to_alipay_dict()
            else:
                params['terminal_bind_info'] = self.terminal_bind_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotDeviceBindInfo()
        if 'app_type' in d:
            o.app_type = d['app_type']
        if 'application_id' in d:
            o.application_id = d['application_id']
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'device_id_type' in d:
            o.device_id_type = d['device_id_type']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'equipment_type' in d:
            o.equipment_type = d['equipment_type']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'external_id_secret' in d:
            o.external_id_secret = d['external_id_secret']
        if 'external_shop_id' in d:
            o.external_shop_id = d['external_shop_id']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'merchant_id_type' in d:
            o.merchant_id_type = d['merchant_id_type']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'source' in d:
            o.source = d['source']
        if 'spi_app_id' in d:
            o.spi_app_id = d['spi_app_id']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        if 'terminal_bind_info' in d:
            o.terminal_bind_info = d['terminal_bind_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FinAttachment import FinAttachment
from alipay.aop.api.domain.CompanyInformation import CompanyInformation
from alipay.aop.api.domain.PersonInfo import PersonInfo
from alipay.aop.api.domain.CreditQuotaDetail import CreditQuotaDetail


class AnttechBlockchainFinanceTruspleCreditgrantapplySubmitModel(object):

    def __init__(self):
        self._attachments = None
        self._borrower_type = None
        self._company_credit_inquiry_request_id = None
        self._company_info = None
        self._ext_info = None
        self._external_credit_grant_id = None
        self._external_product_code = None
        self._external_user_id = None
        self._inst_code = None
        self._legal_person_info = None
        self._personal_credit_inquiry_request_id = None
        self._quota_details = None
        self._risk_info = None

    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, list):
            self._attachments = list()
            for i in value:
                if isinstance(i, FinAttachment):
                    self._attachments.append(i)
                else:
                    self._attachments.append(FinAttachment.from_alipay_dict(i))
    @property
    def borrower_type(self):
        return self._borrower_type

    @borrower_type.setter
    def borrower_type(self, value):
        self._borrower_type = value
    @property
    def company_credit_inquiry_request_id(self):
        return self._company_credit_inquiry_request_id

    @company_credit_inquiry_request_id.setter
    def company_credit_inquiry_request_id(self, value):
        self._company_credit_inquiry_request_id = value
    @property
    def company_info(self):
        return self._company_info

    @company_info.setter
    def company_info(self, value):
        if isinstance(value, CompanyInformation):
            self._company_info = value
        else:
            self._company_info = CompanyInformation.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def external_credit_grant_id(self):
        return self._external_credit_grant_id

    @external_credit_grant_id.setter
    def external_credit_grant_id(self, value):
        self._external_credit_grant_id = value
    @property
    def external_product_code(self):
        return self._external_product_code

    @external_product_code.setter
    def external_product_code(self, value):
        self._external_product_code = value
    @property
    def external_user_id(self):
        return self._external_user_id

    @external_user_id.setter
    def external_user_id(self, value):
        self._external_user_id = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def legal_person_info(self):
        return self._legal_person_info

    @legal_person_info.setter
    def legal_person_info(self, value):
        if isinstance(value, PersonInfo):
            self._legal_person_info = value
        else:
            self._legal_person_info = PersonInfo.from_alipay_dict(value)
    @property
    def personal_credit_inquiry_request_id(self):
        return self._personal_credit_inquiry_request_id

    @personal_credit_inquiry_request_id.setter
    def personal_credit_inquiry_request_id(self, value):
        self._personal_credit_inquiry_request_id = value
    @property
    def quota_details(self):
        return self._quota_details

    @quota_details.setter
    def quota_details(self, value):
        if isinstance(value, list):
            self._quota_details = list()
            for i in value:
                if isinstance(i, CreditQuotaDetail):
                    self._quota_details.append(i)
                else:
                    self._quota_details.append(CreditQuotaDetail.from_alipay_dict(i))
    @property
    def risk_info(self):
        return self._risk_info

    @risk_info.setter
    def risk_info(self, value):
        self._risk_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.attachments:
            if isinstance(self.attachments, list):
                for i in range(0, len(self.attachments)):
                    element = self.attachments[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachments[i] = element.to_alipay_dict()
            if hasattr(self.attachments, 'to_alipay_dict'):
                params['attachments'] = self.attachments.to_alipay_dict()
            else:
                params['attachments'] = self.attachments
        if self.borrower_type:
            if hasattr(self.borrower_type, 'to_alipay_dict'):
                params['borrower_type'] = self.borrower_type.to_alipay_dict()
            else:
                params['borrower_type'] = self.borrower_type
        if self.company_credit_inquiry_request_id:
            if hasattr(self.company_credit_inquiry_request_id, 'to_alipay_dict'):
                params['company_credit_inquiry_request_id'] = self.company_credit_inquiry_request_id.to_alipay_dict()
            else:
                params['company_credit_inquiry_request_id'] = self.company_credit_inquiry_request_id
        if self.company_info:
            if hasattr(self.company_info, 'to_alipay_dict'):
                params['company_info'] = self.company_info.to_alipay_dict()
            else:
                params['company_info'] = self.company_info
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.external_credit_grant_id:
            if hasattr(self.external_credit_grant_id, 'to_alipay_dict'):
                params['external_credit_grant_id'] = self.external_credit_grant_id.to_alipay_dict()
            else:
                params['external_credit_grant_id'] = self.external_credit_grant_id
        if self.external_product_code:
            if hasattr(self.external_product_code, 'to_alipay_dict'):
                params['external_product_code'] = self.external_product_code.to_alipay_dict()
            else:
                params['external_product_code'] = self.external_product_code
        if self.external_user_id:
            if hasattr(self.external_user_id, 'to_alipay_dict'):
                params['external_user_id'] = self.external_user_id.to_alipay_dict()
            else:
                params['external_user_id'] = self.external_user_id
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.legal_person_info:
            if hasattr(self.legal_person_info, 'to_alipay_dict'):
                params['legal_person_info'] = self.legal_person_info.to_alipay_dict()
            else:
                params['legal_person_info'] = self.legal_person_info
        if self.personal_credit_inquiry_request_id:
            if hasattr(self.personal_credit_inquiry_request_id, 'to_alipay_dict'):
                params['personal_credit_inquiry_request_id'] = self.personal_credit_inquiry_request_id.to_alipay_dict()
            else:
                params['personal_credit_inquiry_request_id'] = self.personal_credit_inquiry_request_id
        if self.quota_details:
            if isinstance(self.quota_details, list):
                for i in range(0, len(self.quota_details)):
                    element = self.quota_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.quota_details[i] = element.to_alipay_dict()
            if hasattr(self.quota_details, 'to_alipay_dict'):
                params['quota_details'] = self.quota_details.to_alipay_dict()
            else:
                params['quota_details'] = self.quota_details
        if self.risk_info:
            if hasattr(self.risk_info, 'to_alipay_dict'):
                params['risk_info'] = self.risk_info.to_alipay_dict()
            else:
                params['risk_info'] = self.risk_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTruspleCreditgrantapplySubmitModel()
        if 'attachments' in d:
            o.attachments = d['attachments']
        if 'borrower_type' in d:
            o.borrower_type = d['borrower_type']
        if 'company_credit_inquiry_request_id' in d:
            o.company_credit_inquiry_request_id = d['company_credit_inquiry_request_id']
        if 'company_info' in d:
            o.company_info = d['company_info']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'external_credit_grant_id' in d:
            o.external_credit_grant_id = d['external_credit_grant_id']
        if 'external_product_code' in d:
            o.external_product_code = d['external_product_code']
        if 'external_user_id' in d:
            o.external_user_id = d['external_user_id']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'legal_person_info' in d:
            o.legal_person_info = d['legal_person_info']
        if 'personal_credit_inquiry_request_id' in d:
            o.personal_credit_inquiry_request_id = d['personal_credit_inquiry_request_id']
        if 'quota_details' in d:
            o.quota_details = d['quota_details']
        if 'risk_info' in d:
            o.risk_info = d['risk_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundBatchDetailQueryModel(object):

    def __init__(self):
        self._batch_no = None
        self._biz_code = None
        self._biz_scene = None
        self._detail_no = None
        self._detail_status = None
        self._out_batch_no = None
        self._out_biz_no = None
        self._page_num = None
        self._page_size = None
        self._payee_account = None
        self._product_code = None
        self._sign_principal = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def detail_no(self):
        return self._detail_no

    @detail_no.setter
    def detail_no(self, value):
        self._detail_no = value
    @property
    def detail_status(self):
        return self._detail_status

    @detail_status.setter
    def detail_status(self, value):
        self._detail_status = value
    @property
    def out_batch_no(self):
        return self._out_batch_no

    @out_batch_no.setter
    def out_batch_no(self, value):
        self._out_batch_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def payee_account(self):
        return self._payee_account

    @payee_account.setter
    def payee_account(self, value):
        self._payee_account = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def sign_principal(self):
        return self._sign_principal

    @sign_principal.setter
    def sign_principal(self, value):
        self._sign_principal = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.detail_no:
            if hasattr(self.detail_no, 'to_alipay_dict'):
                params['detail_no'] = self.detail_no.to_alipay_dict()
            else:
                params['detail_no'] = self.detail_no
        if self.detail_status:
            if hasattr(self.detail_status, 'to_alipay_dict'):
                params['detail_status'] = self.detail_status.to_alipay_dict()
            else:
                params['detail_status'] = self.detail_status
        if self.out_batch_no:
            if hasattr(self.out_batch_no, 'to_alipay_dict'):
                params['out_batch_no'] = self.out_batch_no.to_alipay_dict()
            else:
                params['out_batch_no'] = self.out_batch_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.payee_account:
            if hasattr(self.payee_account, 'to_alipay_dict'):
                params['payee_account'] = self.payee_account.to_alipay_dict()
            else:
                params['payee_account'] = self.payee_account
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.sign_principal:
            if hasattr(self.sign_principal, 'to_alipay_dict'):
                params['sign_principal'] = self.sign_principal.to_alipay_dict()
            else:
                params['sign_principal'] = self.sign_principal
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundBatchDetailQueryModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'detail_no' in d:
            o.detail_no = d['detail_no']
        if 'detail_status' in d:
            o.detail_status = d['detail_status']
        if 'out_batch_no' in d:
            o.out_batch_no = d['out_batch_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'payee_account' in d:
            o.payee_account = d['payee_account']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'sign_principal' in d:
            o.sign_principal = d['sign_principal']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoLogisticsExpressOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoLogisticsExpressOrderQueryResponse, self).__init__()
        self._accept_type = None
        self._cancel_cause = None
        self._courier_alipay_account = None
        self._courier_emp_num = None
        self._courier_id_card = None
        self._courier_mobile = None
        self._courier_name = None
        self._create_time = None
        self._fare_claims_amount = None
        self._last_modified_time = None
        self._logis_merch_code = None
        self._order_amount = None
        self._order_no = None
        self._order_status = None
        self._pay_status = None
        self._product_type_change_reason = None
        self._product_type_code = None
        self._site_area_code = None
        self._site_code = None
        self._site_complain_tel = None
        self._site_detail_addr = None
        self._site_leader_mobile = None
        self._site_leader_name = None
        self._site_name = None
        self._trade_amount = None
        self._trade_no = None
        self._way_bill_no = None

    @property
    def accept_type(self):
        return self._accept_type

    @accept_type.setter
    def accept_type(self, value):
        self._accept_type = value
    @property
    def cancel_cause(self):
        return self._cancel_cause

    @cancel_cause.setter
    def cancel_cause(self, value):
        self._cancel_cause = value
    @property
    def courier_alipay_account(self):
        return self._courier_alipay_account

    @courier_alipay_account.setter
    def courier_alipay_account(self, value):
        self._courier_alipay_account = value
    @property
    def courier_emp_num(self):
        return self._courier_emp_num

    @courier_emp_num.setter
    def courier_emp_num(self, value):
        self._courier_emp_num = value
    @property
    def courier_id_card(self):
        return self._courier_id_card

    @courier_id_card.setter
    def courier_id_card(self, value):
        self._courier_id_card = value
    @property
    def courier_mobile(self):
        return self._courier_mobile

    @courier_mobile.setter
    def courier_mobile(self, value):
        self._courier_mobile = value
    @property
    def courier_name(self):
        return self._courier_name

    @courier_name.setter
    def courier_name(self, value):
        self._courier_name = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def fare_claims_amount(self):
        return self._fare_claims_amount

    @fare_claims_amount.setter
    def fare_claims_amount(self, value):
        self._fare_claims_amount = value
    @property
    def last_modified_time(self):
        return self._last_modified_time

    @last_modified_time.setter
    def last_modified_time(self, value):
        self._last_modified_time = value
    @property
    def logis_merch_code(self):
        return self._logis_merch_code

    @logis_merch_code.setter
    def logis_merch_code(self, value):
        self._logis_merch_code = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def pay_status(self):
        return self._pay_status

    @pay_status.setter
    def pay_status(self, value):
        self._pay_status = value
    @property
    def product_type_change_reason(self):
        return self._product_type_change_reason

    @product_type_change_reason.setter
    def product_type_change_reason(self, value):
        self._product_type_change_reason = value
    @property
    def product_type_code(self):
        return self._product_type_code

    @product_type_code.setter
    def product_type_code(self, value):
        self._product_type_code = value
    @property
    def site_area_code(self):
        return self._site_area_code

    @site_area_code.setter
    def site_area_code(self, value):
        self._site_area_code = value
    @property
    def site_code(self):
        return self._site_code

    @site_code.setter
    def site_code(self, value):
        self._site_code = value
    @property
    def site_complain_tel(self):
        return self._site_complain_tel

    @site_complain_tel.setter
    def site_complain_tel(self, value):
        self._site_complain_tel = value
    @property
    def site_detail_addr(self):
        return self._site_detail_addr

    @site_detail_addr.setter
    def site_detail_addr(self, value):
        self._site_detail_addr = value
    @property
    def site_leader_mobile(self):
        return self._site_leader_mobile

    @site_leader_mobile.setter
    def site_leader_mobile(self, value):
        self._site_leader_mobile = value
    @property
    def site_leader_name(self):
        return self._site_leader_name

    @site_leader_name.setter
    def site_leader_name(self, value):
        self._site_leader_name = value
    @property
    def site_name(self):
        return self._site_name

    @site_name.setter
    def site_name(self, value):
        self._site_name = value
    @property
    def trade_amount(self):
        return self._trade_amount

    @trade_amount.setter
    def trade_amount(self, value):
        self._trade_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def way_bill_no(self):
        return self._way_bill_no

    @way_bill_no.setter
    def way_bill_no(self, value):
        self._way_bill_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoLogisticsExpressOrderQueryResponse, self).parse_response_content(response_content)
        if 'accept_type' in response:
            self.accept_type = response['accept_type']
        if 'cancel_cause' in response:
            self.cancel_cause = response['cancel_cause']
        if 'courier_alipay_account' in response:
            self.courier_alipay_account = response['courier_alipay_account']
        if 'courier_emp_num' in response:
            self.courier_emp_num = response['courier_emp_num']
        if 'courier_id_card' in response:
            self.courier_id_card = response['courier_id_card']
        if 'courier_mobile' in response:
            self.courier_mobile = response['courier_mobile']
        if 'courier_name' in response:
            self.courier_name = response['courier_name']
        if 'create_time' in response:
            self.create_time = response['create_time']
        if 'fare_claims_amount' in response:
            self.fare_claims_amount = response['fare_claims_amount']
        if 'last_modified_time' in response:
            self.last_modified_time = response['last_modified_time']
        if 'logis_merch_code' in response:
            self.logis_merch_code = response['logis_merch_code']
        if 'order_amount' in response:
            self.order_amount = response['order_amount']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'pay_status' in response:
            self.pay_status = response['pay_status']
        if 'product_type_change_reason' in response:
            self.product_type_change_reason = response['product_type_change_reason']
        if 'product_type_code' in response:
            self.product_type_code = response['product_type_code']
        if 'site_area_code' in response:
            self.site_area_code = response['site_area_code']
        if 'site_code' in response:
            self.site_code = response['site_code']
        if 'site_complain_tel' in response:
            self.site_complain_tel = response['site_complain_tel']
        if 'site_detail_addr' in response:
            self.site_detail_addr = response['site_detail_addr']
        if 'site_leader_mobile' in response:
            self.site_leader_mobile = response['site_leader_mobile']
        if 'site_leader_name' in response:
            self.site_leader_name = response['site_leader_name']
        if 'site_name' in response:
            self.site_name = response['site_name']
        if 'trade_amount' in response:
            self.trade_amount = response['trade_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'way_bill_no' in response:
            self.way_bill_no = response['way_bill_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.NimitzQueryContext import NimitzQueryContext
from alipay.aop.api.domain.NimitzDimRequest import NimitzDimRequest


class AntfortuneQuotationNimitzDimQueryModel(object):

    def __init__(self):
        self._context = None
        self._ext = None
        self._nimitz_dim_request = None
        self._opt = None
        self._request_id = None

    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        if isinstance(value, NimitzQueryContext):
            self._context = value
        else:
            self._context = NimitzQueryContext.from_alipay_dict(value)
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def nimitz_dim_request(self):
        return self._nimitz_dim_request

    @nimitz_dim_request.setter
    def nimitz_dim_request(self, value):
        if isinstance(value, NimitzDimRequest):
            self._nimitz_dim_request = value
        else:
            self._nimitz_dim_request = NimitzDimRequest.from_alipay_dict(value)
    @property
    def opt(self):
        return self._opt

    @opt.setter
    def opt(self, value):
        self._opt = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.context:
            if hasattr(self.context, 'to_alipay_dict'):
                params['context'] = self.context.to_alipay_dict()
            else:
                params['context'] = self.context
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.nimitz_dim_request:
            if hasattr(self.nimitz_dim_request, 'to_alipay_dict'):
                params['nimitz_dim_request'] = self.nimitz_dim_request.to_alipay_dict()
            else:
                params['nimitz_dim_request'] = self.nimitz_dim_request
        if self.opt:
            if hasattr(self.opt, 'to_alipay_dict'):
                params['opt'] = self.opt.to_alipay_dict()
            else:
                params['opt'] = self.opt
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneQuotationNimitzDimQueryModel()
        if 'context' in d:
            o.context = d['context']
        if 'ext' in d:
            o.ext = d['ext']
        if 'nimitz_dim_request' in d:
            o.nimitz_dim_request = d['nimitz_dim_request']
        if 'opt' in d:
            o.opt = d['opt']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ItemSkuAttrVO import ItemSkuAttrVO


class ItemSkuVO(object):

    def __init__(self):
        self._barcode = None
        self._original_price = None
        self._out_sku_id = None
        self._price_unit = None
        self._sale_price = None
        self._sale_status = None
        self._sku_attrs = None
        self._sku_id = None
        self._stock_num = None
        self._thumb_img = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def out_sku_id(self):
        return self._out_sku_id

    @out_sku_id.setter
    def out_sku_id(self, value):
        self._out_sku_id = value
    @property
    def price_unit(self):
        return self._price_unit

    @price_unit.setter
    def price_unit(self, value):
        self._price_unit = value
    @property
    def sale_price(self):
        return self._sale_price

    @sale_price.setter
    def sale_price(self, value):
        self._sale_price = value
    @property
    def sale_status(self):
        return self._sale_status

    @sale_status.setter
    def sale_status(self, value):
        self._sale_status = value
    @property
    def sku_attrs(self):
        return self._sku_attrs

    @sku_attrs.setter
    def sku_attrs(self, value):
        if isinstance(value, list):
            self._sku_attrs = list()
            for i in value:
                if isinstance(i, ItemSkuAttrVO):
                    self._sku_attrs.append(i)
                else:
                    self._sku_attrs.append(ItemSkuAttrVO.from_alipay_dict(i))
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def stock_num(self):
        return self._stock_num

    @stock_num.setter
    def stock_num(self, value):
        self._stock_num = value
    @property
    def thumb_img(self):
        return self._thumb_img

    @thumb_img.setter
    def thumb_img(self, value):
        self._thumb_img = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.out_sku_id:
            if hasattr(self.out_sku_id, 'to_alipay_dict'):
                params['out_sku_id'] = self.out_sku_id.to_alipay_dict()
            else:
                params['out_sku_id'] = self.out_sku_id
        if self.price_unit:
            if hasattr(self.price_unit, 'to_alipay_dict'):
                params['price_unit'] = self.price_unit.to_alipay_dict()
            else:
                params['price_unit'] = self.price_unit
        if self.sale_price:
            if hasattr(self.sale_price, 'to_alipay_dict'):
                params['sale_price'] = self.sale_price.to_alipay_dict()
            else:
                params['sale_price'] = self.sale_price
        if self.sale_status:
            if hasattr(self.sale_status, 'to_alipay_dict'):
                params['sale_status'] = self.sale_status.to_alipay_dict()
            else:
                params['sale_status'] = self.sale_status
        if self.sku_attrs:
            if isinstance(self.sku_attrs, list):
                for i in range(0, len(self.sku_attrs)):
                    element = self.sku_attrs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_attrs[i] = element.to_alipay_dict()
            if hasattr(self.sku_attrs, 'to_alipay_dict'):
                params['sku_attrs'] = self.sku_attrs.to_alipay_dict()
            else:
                params['sku_attrs'] = self.sku_attrs
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.stock_num:
            if hasattr(self.stock_num, 'to_alipay_dict'):
                params['stock_num'] = self.stock_num.to_alipay_dict()
            else:
                params['stock_num'] = self.stock_num
        if self.thumb_img:
            if hasattr(self.thumb_img, 'to_alipay_dict'):
                params['thumb_img'] = self.thumb_img.to_alipay_dict()
            else:
                params['thumb_img'] = self.thumb_img
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemSkuVO()
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'out_sku_id' in d:
            o.out_sku_id = d['out_sku_id']
        if 'price_unit' in d:
            o.price_unit = d['price_unit']
        if 'sale_price' in d:
            o.sale_price = d['sale_price']
        if 'sale_status' in d:
            o.sale_status = d['sale_status']
        if 'sku_attrs' in d:
            o.sku_attrs = d['sku_attrs']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'stock_num' in d:
            o.stock_num = d['stock_num']
        if 'thumb_img' in d:
            o.thumb_img = d['thumb_img']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RatioDetail(object):

    def __init__(self):
        self._area_code = None
        self._area_name = None
        self._id = None
        self._period = None
        self._ratio_label = None
        self._ratio_val = None

    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def ratio_label(self):
        return self._ratio_label

    @ratio_label.setter
    def ratio_label(self, value):
        self._ratio_label = value
    @property
    def ratio_val(self):
        return self._ratio_val

    @ratio_val.setter
    def ratio_val(self, value):
        self._ratio_val = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.ratio_label:
            if hasattr(self.ratio_label, 'to_alipay_dict'):
                params['ratio_label'] = self.ratio_label.to_alipay_dict()
            else:
                params['ratio_label'] = self.ratio_label
        if self.ratio_val:
            if hasattr(self.ratio_val, 'to_alipay_dict'):
                params['ratio_val'] = self.ratio_val.to_alipay_dict()
            else:
                params['ratio_val'] = self.ratio_val
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RatioDetail()
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'id' in d:
            o.id = d['id']
        if 'period' in d:
            o.period = d['period']
        if 'ratio_label' in d:
            o.ratio_label = d['ratio_label']
        if 'ratio_val' in d:
            o.ratio_val = d['ratio_val']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContentItem(object):

    def __init__(self):
        self._author_fans = None
        self._author_id = None
        self._author_level = None
        self._author_name = None
        self._cate = None
        self._cate_cnt = None
        self._collect_cnt = None
        self._collection = None
        self._comment_cnt = None
        self._content = None
        self._copyright_end = None
        self._copyright_start = None
        self._create_time = None
        self._detail_pic_num = None
        self._detail_url = None
        self._expire_time = None
        self._id = None
        self._key_word = None
        self._location_tag = None
        self._mini_app_id = None
        self._pic_url = None
        self._praise_cnt = None
        self._pub_time = None
        self._rating = None
        self._related_goods_ids = None
        self._share_cnt = None
        self._source_id = None
        self._status = None
        self._tags = None
        self._title = None
        self._topic_tag = None
        self._type = None
        self._update_time = None
        self._video_duration = None
        self._video_url = None

    @property
    def author_fans(self):
        return self._author_fans

    @author_fans.setter
    def author_fans(self, value):
        self._author_fans = value
    @property
    def author_id(self):
        return self._author_id

    @author_id.setter
    def author_id(self, value):
        self._author_id = value
    @property
    def author_level(self):
        return self._author_level

    @author_level.setter
    def author_level(self, value):
        self._author_level = value
    @property
    def author_name(self):
        return self._author_name

    @author_name.setter
    def author_name(self, value):
        self._author_name = value
    @property
    def cate(self):
        return self._cate

    @cate.setter
    def cate(self, value):
        self._cate = value
    @property
    def cate_cnt(self):
        return self._cate_cnt

    @cate_cnt.setter
    def cate_cnt(self, value):
        self._cate_cnt = value
    @property
    def collect_cnt(self):
        return self._collect_cnt

    @collect_cnt.setter
    def collect_cnt(self, value):
        self._collect_cnt = value
    @property
    def collection(self):
        return self._collection

    @collection.setter
    def collection(self, value):
        self._collection = value
    @property
    def comment_cnt(self):
        return self._comment_cnt

    @comment_cnt.setter
    def comment_cnt(self, value):
        self._comment_cnt = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def copyright_end(self):
        return self._copyright_end

    @copyright_end.setter
    def copyright_end(self, value):
        self._copyright_end = value
    @property
    def copyright_start(self):
        return self._copyright_start

    @copyright_start.setter
    def copyright_start(self, value):
        self._copyright_start = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def detail_pic_num(self):
        return self._detail_pic_num

    @detail_pic_num.setter
    def detail_pic_num(self, value):
        self._detail_pic_num = value
    @property
    def detail_url(self):
        return self._detail_url

    @detail_url.setter
    def detail_url(self, value):
        self._detail_url = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def key_word(self):
        return self._key_word

    @key_word.setter
    def key_word(self, value):
        if isinstance(value, list):
            self._key_word = list()
            for i in value:
                self._key_word.append(i)
    @property
    def location_tag(self):
        return self._location_tag

    @location_tag.setter
    def location_tag(self, value):
        self._location_tag = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def pic_url(self):
        return self._pic_url

    @pic_url.setter
    def pic_url(self, value):
        self._pic_url = value
    @property
    def praise_cnt(self):
        return self._praise_cnt

    @praise_cnt.setter
    def praise_cnt(self, value):
        self._praise_cnt = value
    @property
    def pub_time(self):
        return self._pub_time

    @pub_time.setter
    def pub_time(self, value):
        self._pub_time = value
    @property
    def rating(self):
        return self._rating

    @rating.setter
    def rating(self, value):
        self._rating = value
    @property
    def related_goods_ids(self):
        return self._related_goods_ids

    @related_goods_ids.setter
    def related_goods_ids(self, value):
        self._related_goods_ids = value
    @property
    def share_cnt(self):
        return self._share_cnt

    @share_cnt.setter
    def share_cnt(self, value):
        self._share_cnt = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def topic_tag(self):
        return self._topic_tag

    @topic_tag.setter
    def topic_tag(self, value):
        self._topic_tag = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value
    @property
    def video_duration(self):
        return self._video_duration

    @video_duration.setter
    def video_duration(self, value):
        self._video_duration = value
    @property
    def video_url(self):
        return self._video_url

    @video_url.setter
    def video_url(self, value):
        self._video_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.author_fans:
            if hasattr(self.author_fans, 'to_alipay_dict'):
                params['author_fans'] = self.author_fans.to_alipay_dict()
            else:
                params['author_fans'] = self.author_fans
        if self.author_id:
            if hasattr(self.author_id, 'to_alipay_dict'):
                params['author_id'] = self.author_id.to_alipay_dict()
            else:
                params['author_id'] = self.author_id
        if self.author_level:
            if hasattr(self.author_level, 'to_alipay_dict'):
                params['author_level'] = self.author_level.to_alipay_dict()
            else:
                params['author_level'] = self.author_level
        if self.author_name:
            if hasattr(self.author_name, 'to_alipay_dict'):
                params['author_name'] = self.author_name.to_alipay_dict()
            else:
                params['author_name'] = self.author_name
        if self.cate:
            if hasattr(self.cate, 'to_alipay_dict'):
                params['cate'] = self.cate.to_alipay_dict()
            else:
                params['cate'] = self.cate
        if self.cate_cnt:
            if hasattr(self.cate_cnt, 'to_alipay_dict'):
                params['cate_cnt'] = self.cate_cnt.to_alipay_dict()
            else:
                params['cate_cnt'] = self.cate_cnt
        if self.collect_cnt:
            if hasattr(self.collect_cnt, 'to_alipay_dict'):
                params['collect_cnt'] = self.collect_cnt.to_alipay_dict()
            else:
                params['collect_cnt'] = self.collect_cnt
        if self.collection:
            if hasattr(self.collection, 'to_alipay_dict'):
                params['collection'] = self.collection.to_alipay_dict()
            else:
                params['collection'] = self.collection
        if self.comment_cnt:
            if hasattr(self.comment_cnt, 'to_alipay_dict'):
                params['comment_cnt'] = self.comment_cnt.to_alipay_dict()
            else:
                params['comment_cnt'] = self.comment_cnt
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.copyright_end:
            if hasattr(self.copyright_end, 'to_alipay_dict'):
                params['copyright_end'] = self.copyright_end.to_alipay_dict()
            else:
                params['copyright_end'] = self.copyright_end
        if self.copyright_start:
            if hasattr(self.copyright_start, 'to_alipay_dict'):
                params['copyright_start'] = self.copyright_start.to_alipay_dict()
            else:
                params['copyright_start'] = self.copyright_start
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.detail_pic_num:
            if hasattr(self.detail_pic_num, 'to_alipay_dict'):
                params['detail_pic_num'] = self.detail_pic_num.to_alipay_dict()
            else:
                params['detail_pic_num'] = self.detail_pic_num
        if self.detail_url:
            if hasattr(self.detail_url, 'to_alipay_dict'):
                params['detail_url'] = self.detail_url.to_alipay_dict()
            else:
                params['detail_url'] = self.detail_url
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.key_word:
            if isinstance(self.key_word, list):
                for i in range(0, len(self.key_word)):
                    element = self.key_word[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.key_word[i] = element.to_alipay_dict()
            if hasattr(self.key_word, 'to_alipay_dict'):
                params['key_word'] = self.key_word.to_alipay_dict()
            else:
                params['key_word'] = self.key_word
        if self.location_tag:
            if hasattr(self.location_tag, 'to_alipay_dict'):
                params['location_tag'] = self.location_tag.to_alipay_dict()
            else:
                params['location_tag'] = self.location_tag
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.pic_url:
            if hasattr(self.pic_url, 'to_alipay_dict'):
                params['pic_url'] = self.pic_url.to_alipay_dict()
            else:
                params['pic_url'] = self.pic_url
        if self.praise_cnt:
            if hasattr(self.praise_cnt, 'to_alipay_dict'):
                params['praise_cnt'] = self.praise_cnt.to_alipay_dict()
            else:
                params['praise_cnt'] = self.praise_cnt
        if self.pub_time:
            if hasattr(self.pub_time, 'to_alipay_dict'):
                params['pub_time'] = self.pub_time.to_alipay_dict()
            else:
                params['pub_time'] = self.pub_time
        if self.rating:
            if hasattr(self.rating, 'to_alipay_dict'):
                params['rating'] = self.rating.to_alipay_dict()
            else:
                params['rating'] = self.rating
        if self.related_goods_ids:
            if hasattr(self.related_goods_ids, 'to_alipay_dict'):
                params['related_goods_ids'] = self.related_goods_ids.to_alipay_dict()
            else:
                params['related_goods_ids'] = self.related_goods_ids
        if self.share_cnt:
            if hasattr(self.share_cnt, 'to_alipay_dict'):
                params['share_cnt'] = self.share_cnt.to_alipay_dict()
            else:
                params['share_cnt'] = self.share_cnt
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.topic_tag:
            if hasattr(self.topic_tag, 'to_alipay_dict'):
                params['topic_tag'] = self.topic_tag.to_alipay_dict()
            else:
                params['topic_tag'] = self.topic_tag
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.update_time:
            if hasattr(self.update_time, 'to_alipay_dict'):
                params['update_time'] = self.update_time.to_alipay_dict()
            else:
                params['update_time'] = self.update_time
        if self.video_duration:
            if hasattr(self.video_duration, 'to_alipay_dict'):
                params['video_duration'] = self.video_duration.to_alipay_dict()
            else:
                params['video_duration'] = self.video_duration
        if self.video_url:
            if hasattr(self.video_url, 'to_alipay_dict'):
                params['video_url'] = self.video_url.to_alipay_dict()
            else:
                params['video_url'] = self.video_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContentItem()
        if 'author_fans' in d:
            o.author_fans = d['author_fans']
        if 'author_id' in d:
            o.author_id = d['author_id']
        if 'author_level' in d:
            o.author_level = d['author_level']
        if 'author_name' in d:
            o.author_name = d['author_name']
        if 'cate' in d:
            o.cate = d['cate']
        if 'cate_cnt' in d:
            o.cate_cnt = d['cate_cnt']
        if 'collect_cnt' in d:
            o.collect_cnt = d['collect_cnt']
        if 'collection' in d:
            o.collection = d['collection']
        if 'comment_cnt' in d:
            o.comment_cnt = d['comment_cnt']
        if 'content' in d:
            o.content = d['content']
        if 'copyright_end' in d:
            o.copyright_end = d['copyright_end']
        if 'copyright_start' in d:
            o.copyright_start = d['copyright_start']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'detail_pic_num' in d:
            o.detail_pic_num = d['detail_pic_num']
        if 'detail_url' in d:
            o.detail_url = d['detail_url']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'id' in d:
            o.id = d['id']
        if 'key_word' in d:
            o.key_word = d['key_word']
        if 'location_tag' in d:
            o.location_tag = d['location_tag']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'pic_url' in d:
            o.pic_url = d['pic_url']
        if 'praise_cnt' in d:
            o.praise_cnt = d['praise_cnt']
        if 'pub_time' in d:
            o.pub_time = d['pub_time']
        if 'rating' in d:
            o.rating = d['rating']
        if 'related_goods_ids' in d:
            o.related_goods_ids = d['related_goods_ids']
        if 'share_cnt' in d:
            o.share_cnt = d['share_cnt']
        if 'source_id' in d:
            o.source_id = d['source_id']
        if 'status' in d:
            o.status = d['status']
        if 'tags' in d:
            o.tags = d['tags']
        if 'title' in d:
            o.title = d['title']
        if 'topic_tag' in d:
            o.topic_tag = d['topic_tag']
        if 'type' in d:
            o.type = d['type']
        if 'update_time' in d:
            o.update_time = d['update_time']
        if 'video_duration' in d:
            o.video_duration = d['video_duration']
        if 'video_url' in d:
            o.video_url = d['video_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandIotdeviceOnlinedataUploadResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandIotdeviceOnlinedataUploadResponse, self).__init__()
        self._onlinedata_upload_result = None

    @property
    def onlinedata_upload_result(self):
        return self._onlinedata_upload_result

    @onlinedata_upload_result.setter
    def onlinedata_upload_result(self, value):
        self._onlinedata_upload_result = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandIotdeviceOnlinedataUploadResponse, self).parse_response_content(response_content)
        if 'onlinedata_upload_result' in response:
            self.onlinedata_upload_result = response['onlinedata_upload_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayYebLqdDataResult(object):

    def __init__(self):
        self._predict_purchase_amt = None
        self._predict_redeem_amt = None
        self._target_date = None

    @property
    def predict_purchase_amt(self):
        return self._predict_purchase_amt

    @predict_purchase_amt.setter
    def predict_purchase_amt(self, value):
        self._predict_purchase_amt = value
    @property
    def predict_redeem_amt(self):
        return self._predict_redeem_amt

    @predict_redeem_amt.setter
    def predict_redeem_amt(self, value):
        self._predict_redeem_amt = value
    @property
    def target_date(self):
        return self._target_date

    @target_date.setter
    def target_date(self, value):
        self._target_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.predict_purchase_amt:
            if hasattr(self.predict_purchase_amt, 'to_alipay_dict'):
                params['predict_purchase_amt'] = self.predict_purchase_amt.to_alipay_dict()
            else:
                params['predict_purchase_amt'] = self.predict_purchase_amt
        if self.predict_redeem_amt:
            if hasattr(self.predict_redeem_amt, 'to_alipay_dict'):
                params['predict_redeem_amt'] = self.predict_redeem_amt.to_alipay_dict()
            else:
                params['predict_redeem_amt'] = self.predict_redeem_amt
        if self.target_date:
            if hasattr(self.target_date, 'to_alipay_dict'):
                params['target_date'] = self.target_date.to_alipay_dict()
            else:
                params['target_date'] = self.target_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayYebLqdDataResult()
        if 'predict_purchase_amt' in d:
            o.predict_purchase_amt = d['predict_purchase_amt']
        if 'predict_redeem_amt' in d:
            o.predict_redeem_amt = d['predict_redeem_amt']
        if 'target_date' in d:
            o.target_date = d['target_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Reasons(object):

    def __init__(self):
        self._problem_pic = None
        self._remark = None
        self._risk_name = None

    @property
    def problem_pic(self):
        return self._problem_pic

    @problem_pic.setter
    def problem_pic(self, value):
        if isinstance(value, list):
            self._problem_pic = list()
            for i in value:
                self._problem_pic.append(i)
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def risk_name(self):
        return self._risk_name

    @risk_name.setter
    def risk_name(self, value):
        self._risk_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.problem_pic:
            if isinstance(self.problem_pic, list):
                for i in range(0, len(self.problem_pic)):
                    element = self.problem_pic[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.problem_pic[i] = element.to_alipay_dict()
            if hasattr(self.problem_pic, 'to_alipay_dict'):
                params['problem_pic'] = self.problem_pic.to_alipay_dict()
            else:
                params['problem_pic'] = self.problem_pic
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.risk_name:
            if hasattr(self.risk_name, 'to_alipay_dict'):
                params['risk_name'] = self.risk_name.to_alipay_dict()
            else:
                params['risk_name'] = self.risk_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Reasons()
        if 'problem_pic' in d:
            o.problem_pic = d['problem_pic']
        if 'remark' in d:
            o.remark = d['remark']
        if 'risk_name' in d:
            o.risk_name = d['risk_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppIsvImportedbillQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._charge_inst = None
        self._end_date = None
        self._org_code = None
        self._start_date = None
        self._sub_biz_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppIsvImportedbillQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSearchSubservicekeywordApplyModel(object):

    def __init__(self):
        self._config_id = None
        self._key_words = None
        self._sub_service_code = None
        self._target_appid = None

    @property
    def config_id(self):
        return self._config_id

    @config_id.setter
    def config_id(self, value):
        self._config_id = value
    @property
    def key_words(self):
        return self._key_words

    @key_words.setter
    def key_words(self, value):
        if isinstance(value, list):
            self._key_words = list()
            for i in value:
                self._key_words.append(i)
    @property
    def sub_service_code(self):
        return self._sub_service_code

    @sub_service_code.setter
    def sub_service_code(self, value):
        self._sub_service_code = value
    @property
    def target_appid(self):
        return self._target_appid

    @target_appid.setter
    def target_appid(self, value):
        self._target_appid = value


    def to_alipay_dict(self):
        params = dict()
        if self.config_id:
            if hasattr(self.config_id, 'to_alipay_dict'):
                params['config_id'] = self.config_id.to_alipay_dict()
            else:
                params['config_id'] = self.config_id
        if self.key_words:
            if isinstance(self.key_words, list):
                for i in range(0, len(self.key_words)):
                    element = self.key_words[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.key_words[i] = element.to_alipay_dict()
            if hasattr(self.key_words, 'to_alipay_dict'):
                params['key_words'] = self.key_words.to_alipay_dict()
            else:
                params['key_words'] = self.key_words
        if self.sub_service_code:
            if hasattr(self.sub_service_code, 'to_alipay_dict'):
                params['sub_service_code'] = self.sub_service_code.to_alipay_dict()
            else:
                params['sub_service_code'] = self.sub_service_code
        if self.target_appid:
            if hasattr(self.target_appid, 'to_alipay_dict'):
                params['target_appid'] = self.target_appid.to_alipay_dict()
            else:
                params['target_appid'] = self.target_appid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSearchSubservicekeywordApplyModel()
        if 'config_id' in d:
            o.config_id = d['config_id']
        if 'key_words' in d:
            o.key_words = d['key_words']
        if 'sub_service_code' in d:
            o.sub_service_code = d['sub_service_code']
        if 'target_appid' in d:
            o.target_appid = d['target_appid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ProjectTimeTable(object):

    def __init__(self):
        self._begin_date = None
        self._content = None
        self._end_date = None
        self._remark = None

    @property
    def begin_date(self):
        return self._begin_date

    @begin_date.setter
    def begin_date(self, value):
        self._begin_date = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.begin_date:
            if hasattr(self.begin_date, 'to_alipay_dict'):
                params['begin_date'] = self.begin_date.to_alipay_dict()
            else:
                params['begin_date'] = self.begin_date
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ProjectTimeTable()
        if 'begin_date' in d:
            o.begin_date = d['begin_date']
        if 'content' in d:
            o.content = d['content']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BankSubAccountBaseInfoDTO(object):

    def __init__(self):
        self._account_no = None
        self._account_no_4_credit_transfer = None
        self._country_code = None
        self._currency = None
        self._global_account_name = None
        self._global_bank_name = None
        self._global_branch_name = None
        self._global_sub_bank_name = None
        self._local_account_name = None
        self._local_bank_name = None
        self._local_bank_name_4_transfer = None
        self._local_branch_name = None
        self._local_sub_bank_name = None
        self._out_fin_inst_abbreviation = None
        self._sub_account_no = None
        self._treasury_biz_type = None
        self._treasury_biz_type_name = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_no_4_credit_transfer(self):
        return self._account_no_4_credit_transfer

    @account_no_4_credit_transfer.setter
    def account_no_4_credit_transfer(self, value):
        self._account_no_4_credit_transfer = value
    @property
    def country_code(self):
        return self._country_code

    @country_code.setter
    def country_code(self, value):
        self._country_code = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def global_account_name(self):
        return self._global_account_name

    @global_account_name.setter
    def global_account_name(self, value):
        self._global_account_name = value
    @property
    def global_bank_name(self):
        return self._global_bank_name

    @global_bank_name.setter
    def global_bank_name(self, value):
        self._global_bank_name = value
    @property
    def global_branch_name(self):
        return self._global_branch_name

    @global_branch_name.setter
    def global_branch_name(self, value):
        self._global_branch_name = value
    @property
    def global_sub_bank_name(self):
        return self._global_sub_bank_name

    @global_sub_bank_name.setter
    def global_sub_bank_name(self, value):
        self._global_sub_bank_name = value
    @property
    def local_account_name(self):
        return self._local_account_name

    @local_account_name.setter
    def local_account_name(self, value):
        self._local_account_name = value
    @property
    def local_bank_name(self):
        return self._local_bank_name

    @local_bank_name.setter
    def local_bank_name(self, value):
        self._local_bank_name = value
    @property
    def local_bank_name_4_transfer(self):
        return self._local_bank_name_4_transfer

    @local_bank_name_4_transfer.setter
    def local_bank_name_4_transfer(self, value):
        self._local_bank_name_4_transfer = value
    @property
    def local_branch_name(self):
        return self._local_branch_name

    @local_branch_name.setter
    def local_branch_name(self, value):
        self._local_branch_name = value
    @property
    def local_sub_bank_name(self):
        return self._local_sub_bank_name

    @local_sub_bank_name.setter
    def local_sub_bank_name(self, value):
        self._local_sub_bank_name = value
    @property
    def out_fin_inst_abbreviation(self):
        return self._out_fin_inst_abbreviation

    @out_fin_inst_abbreviation.setter
    def out_fin_inst_abbreviation(self, value):
        self._out_fin_inst_abbreviation = value
    @property
    def sub_account_no(self):
        return self._sub_account_no

    @sub_account_no.setter
    def sub_account_no(self, value):
        self._sub_account_no = value
    @property
    def treasury_biz_type(self):
        return self._treasury_biz_type

    @treasury_biz_type.setter
    def treasury_biz_type(self, value):
        self._treasury_biz_type = value
    @property
    def treasury_biz_type_name(self):
        return self._treasury_biz_type_name

    @treasury_biz_type_name.setter
    def treasury_biz_type_name(self, value):
        self._treasury_biz_type_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_no_4_credit_transfer:
            if hasattr(self.account_no_4_credit_transfer, 'to_alipay_dict'):
                params['account_no_4_credit_transfer'] = self.account_no_4_credit_transfer.to_alipay_dict()
            else:
                params['account_no_4_credit_transfer'] = self.account_no_4_credit_transfer
        if self.country_code:
            if hasattr(self.country_code, 'to_alipay_dict'):
                params['country_code'] = self.country_code.to_alipay_dict()
            else:
                params['country_code'] = self.country_code
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.global_account_name:
            if hasattr(self.global_account_name, 'to_alipay_dict'):
                params['global_account_name'] = self.global_account_name.to_alipay_dict()
            else:
                params['global_account_name'] = self.global_account_name
        if self.global_bank_name:
            if hasattr(self.global_bank_name, 'to_alipay_dict'):
                params['global_bank_name'] = self.global_bank_name.to_alipay_dict()
            else:
                params['global_bank_name'] = self.global_bank_name
        if self.global_branch_name:
            if hasattr(self.global_branch_name, 'to_alipay_dict'):
                params['global_branch_name'] = self.global_branch_name.to_alipay_dict()
            else:
                params['global_branch_name'] = self.global_branch_name
        if self.global_sub_bank_name:
            if hasattr(self.global_sub_bank_name, 'to_alipay_dict'):
                params['global_sub_bank_name'] = self.global_sub_bank_name.to_alipay_dict()
            else:
                params['global_sub_bank_name'] = self.global_sub_bank_name
        if self.local_account_name:
            if hasattr(self.local_account_name, 'to_alipay_dict'):
                params['local_account_name'] = self.local_account_name.to_alipay_dict()
            else:
                params['local_account_name'] = self.local_account_name
        if self.local_bank_name:
            if hasattr(self.local_bank_name, 'to_alipay_dict'):
                params['local_bank_name'] = self.local_bank_name.to_alipay_dict()
            else:
                params['local_bank_name'] = self.local_bank_name
        if self.local_bank_name_4_transfer:
            if hasattr(self.local_bank_name_4_transfer, 'to_alipay_dict'):
                params['local_bank_name_4_transfer'] = self.local_bank_name_4_transfer.to_alipay_dict()
            else:
                params['local_bank_name_4_transfer'] = self.local_bank_name_4_transfer
        if self.local_branch_name:
            if hasattr(self.local_branch_name, 'to_alipay_dict'):
                params['local_branch_name'] = self.local_branch_name.to_alipay_dict()
            else:
                params['local_branch_name'] = self.local_branch_name
        if self.local_sub_bank_name:
            if hasattr(self.local_sub_bank_name, 'to_alipay_dict'):
                params['local_sub_bank_name'] = self.local_sub_bank_name.to_alipay_dict()
            else:
                params['local_sub_bank_name'] = self.local_sub_bank_name
        if self.out_fin_inst_abbreviation:
            if hasattr(self.out_fin_inst_abbreviation, 'to_alipay_dict'):
                params['out_fin_inst_abbreviation'] = self.out_fin_inst_abbreviation.to_alipay_dict()
            else:
                params['out_fin_inst_abbreviation'] = self.out_fin_inst_abbreviation
        if self.sub_account_no:
            if hasattr(self.sub_account_no, 'to_alipay_dict'):
                params['sub_account_no'] = self.sub_account_no.to_alipay_dict()
            else:
                params['sub_account_no'] = self.sub_account_no
        if self.treasury_biz_type:
            if hasattr(self.treasury_biz_type, 'to_alipay_dict'):
                params['treasury_biz_type'] = self.treasury_biz_type.to_alipay_dict()
            else:
                params['treasury_biz_type'] = self.treasury_biz_type
        if self.treasury_biz_type_name:
            if hasattr(self.treasury_biz_type_name, 'to_alipay_dict'):
                params['treasury_biz_type_name'] = self.treasury_biz_type_name.to_alipay_dict()
            else:
                params['treasury_biz_type_name'] = self.treasury_biz_type_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BankSubAccountBaseInfoDTO()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_no_4_credit_transfer' in d:
            o.account_no_4_credit_transfer = d['account_no_4_credit_transfer']
        if 'country_code' in d:
            o.country_code = d['country_code']
        if 'currency' in d:
            o.currency = d['currency']
        if 'global_account_name' in d:
            o.global_account_name = d['global_account_name']
        if 'global_bank_name' in d:
            o.global_bank_name = d['global_bank_name']
        if 'global_branch_name' in d:
            o.global_branch_name = d['global_branch_name']
        if 'global_sub_bank_name' in d:
            o.global_sub_bank_name = d['global_sub_bank_name']
        if 'local_account_name' in d:
            o.local_account_name = d['local_account_name']
        if 'local_bank_name' in d:
            o.local_bank_name = d['local_bank_name']
        if 'local_bank_name_4_transfer' in d:
            o.local_bank_name_4_transfer = d['local_bank_name_4_transfer']
        if 'local_branch_name' in d:
            o.local_branch_name = d['local_branch_name']
        if 'local_sub_bank_name' in d:
            o.local_sub_bank_name = d['local_sub_bank_name']
        if 'out_fin_inst_abbreviation' in d:
            o.out_fin_inst_abbreviation = d['out_fin_inst_abbreviation']
        if 'sub_account_no' in d:
            o.sub_account_no = d['sub_account_no']
        if 'treasury_biz_type' in d:
            o.treasury_biz_type = d['treasury_biz_type']
        if 'treasury_biz_type_name' in d:
            o.treasury_biz_type_name = d['treasury_biz_type_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbAdvertCommissionClauseQuotaResponse(object):

    def __init__(self):
        self._quota_amount = None

    @property
    def quota_amount(self):
        return self._quota_amount

    @quota_amount.setter
    def quota_amount(self, value):
        self._quota_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.quota_amount:
            if hasattr(self.quota_amount, 'to_alipay_dict'):
                params['quota_amount'] = self.quota_amount.to_alipay_dict()
            else:
                params['quota_amount'] = self.quota_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertCommissionClauseQuotaResponse()
        if 'quota_amount' in d:
            o.quota_amount = d['quota_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserCertifyVerificationQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserCertifyVerificationQueryResponse, self).__init__()
        self._mismatch_reason = None
        self._result_code = None
        self._result_msg = None
        self._score = None
        self._source_from = None

    @property
    def mismatch_reason(self):
        return self._mismatch_reason

    @mismatch_reason.setter
    def mismatch_reason(self, value):
        self._mismatch_reason = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def source_from(self):
        return self._source_from

    @source_from.setter
    def source_from(self, value):
        self._source_from = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserCertifyVerificationQueryResponse, self).parse_response_content(response_content)
        if 'mismatch_reason' in response:
            self.mismatch_reason = response['mismatch_reason']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']
        if 'score' in response:
            self.score = response['score']
        if 'source_from' in response:
            self.source_from = response['source_from']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BoxExclusiveKeyword(object):

    def __init__(self):
        self._default_keywords = None
        self._keywords = None

    @property
    def default_keywords(self):
        return self._default_keywords

    @default_keywords.setter
    def default_keywords(self, value):
        if isinstance(value, list):
            self._default_keywords = list()
            for i in value:
                self._default_keywords.append(i)
    @property
    def keywords(self):
        return self._keywords

    @keywords.setter
    def keywords(self, value):
        if isinstance(value, list):
            self._keywords = list()
            for i in value:
                self._keywords.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.default_keywords:
            if isinstance(self.default_keywords, list):
                for i in range(0, len(self.default_keywords)):
                    element = self.default_keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.default_keywords[i] = element.to_alipay_dict()
            if hasattr(self.default_keywords, 'to_alipay_dict'):
                params['default_keywords'] = self.default_keywords.to_alipay_dict()
            else:
                params['default_keywords'] = self.default_keywords
        if self.keywords:
            if isinstance(self.keywords, list):
                for i in range(0, len(self.keywords)):
                    element = self.keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.keywords[i] = element.to_alipay_dict()
            if hasattr(self.keywords, 'to_alipay_dict'):
                params['keywords'] = self.keywords.to_alipay_dict()
            else:
                params['keywords'] = self.keywords
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BoxExclusiveKeyword()
        if 'default_keywords' in d:
            o.default_keywords = d['default_keywords']
        if 'keywords' in d:
            o.keywords = d['keywords']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceKidsAccountModifyModel(object):

    def __init__(self):
        self._birthday = None
        self._mobile = None
        self._name = None
        self._out_biz_id = None
        self._out_biz_type = None
        self._scene_code = None

    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceKidsAccountModifyModel()
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchQueryBoxExclusiveServiceInfoRequest(object):

    def __init__(self):
        self._brand_id = None
        self._pid = None
        self._spec_code = None

    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def spec_code(self):
        return self._spec_code

    @spec_code.setter
    def spec_code(self, value):
        self._spec_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.spec_code:
            if hasattr(self.spec_code, 'to_alipay_dict'):
                params['spec_code'] = self.spec_code.to_alipay_dict()
            else:
                params['spec_code'] = self.spec_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchQueryBoxExclusiveServiceInfoRequest()
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'pid' in d:
            o.pid = d['pid']
        if 'spec_code' in d:
            o.spec_code = d['spec_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoCityserviceIndustryEnergyCheckResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCityserviceIndustryEnergyCheckResponse, self).__init__()
        self._limited = None

    @property
    def limited(self):
        return self._limited

    @limited.setter
    def limited(self, value):
        self._limited = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCityserviceIndustryEnergyCheckResponse, self).parse_response_content(response_content)
        if 'limited' in response:
            self.limited = response['limited']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserCertifyImgUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserCertifyImgUploadResponse, self).__init__()
        self._certificate_id = None
        self._pic_url = None

    @property
    def certificate_id(self):
        return self._certificate_id

    @certificate_id.setter
    def certificate_id(self, value):
        self._certificate_id = value
    @property
    def pic_url(self):
        return self._pic_url

    @pic_url.setter
    def pic_url(self, value):
        self._pic_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserCertifyImgUploadResponse, self).parse_response_content(response_content)
        if 'certificate_id' in response:
            self.certificate_id = response['certificate_id']
        if 'pic_url' in response:
            self.pic_url = response['pic_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StockShippingStepInfo(object):

    def __init__(self):
        self._event_address = None
        self._event_time = None
        self._ext_info = None
        self._status = None

    @property
    def event_address(self):
        return self._event_address

    @event_address.setter
    def event_address(self, value):
        self._event_address = value
    @property
    def event_time(self):
        return self._event_time

    @event_time.setter
    def event_time(self, value):
        self._event_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.event_address:
            if hasattr(self.event_address, 'to_alipay_dict'):
                params['event_address'] = self.event_address.to_alipay_dict()
            else:
                params['event_address'] = self.event_address
        if self.event_time:
            if hasattr(self.event_time, 'to_alipay_dict'):
                params['event_time'] = self.event_time.to_alipay_dict()
            else:
                params['event_time'] = self.event_time
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StockShippingStepInfo()
        if 'event_address' in d:
            o.event_address = d['event_address']
        if 'event_time' in d:
            o.event_time = d['event_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PageTemplateParamInfoDTO import PageTemplateParamInfoDTO


class AlipaySecurityYyuDvsdvdsBatchqueryModel(object):

    def __init__(self):
        self._asd = None
        self._asdasda = None
        self._asdf = None
        self._sadf = None
        self._yuyu = None

    @property
    def asd(self):
        return self._asd

    @asd.setter
    def asd(self, value):
        if isinstance(value, PageTemplateParamInfoDTO):
            self._asd = value
        else:
            self._asd = PageTemplateParamInfoDTO.from_alipay_dict(value)
    @property
    def asdasda(self):
        return self._asdasda

    @asdasda.setter
    def asdasda(self, value):
        self._asdasda = value
    @property
    def asdf(self):
        return self._asdf

    @asdf.setter
    def asdf(self, value):
        self._asdf = value
    @property
    def sadf(self):
        return self._sadf

    @sadf.setter
    def sadf(self, value):
        self._sadf = value
    @property
    def yuyu(self):
        return self._yuyu

    @yuyu.setter
    def yuyu(self, value):
        self._yuyu = value


    def to_alipay_dict(self):
        params = dict()
        if self.asd:
            if hasattr(self.asd, 'to_alipay_dict'):
                params['asd'] = self.asd.to_alipay_dict()
            else:
                params['asd'] = self.asd
        if self.asdasda:
            if hasattr(self.asdasda, 'to_alipay_dict'):
                params['asdasda'] = self.asdasda.to_alipay_dict()
            else:
                params['asdasda'] = self.asdasda
        if self.asdf:
            if hasattr(self.asdf, 'to_alipay_dict'):
                params['asdf'] = self.asdf.to_alipay_dict()
            else:
                params['asdf'] = self.asdf
        if self.sadf:
            if hasattr(self.sadf, 'to_alipay_dict'):
                params['sadf'] = self.sadf.to_alipay_dict()
            else:
                params['sadf'] = self.sadf
        if self.yuyu:
            if hasattr(self.yuyu, 'to_alipay_dict'):
                params['yuyu'] = self.yuyu.to_alipay_dict()
            else:
                params['yuyu'] = self.yuyu
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityYyuDvsdvdsBatchqueryModel()
        if 'asd' in d:
            o.asd = d['asd']
        if 'asdasda' in d:
            o.asdasda = d['asdasda']
        if 'asdf' in d:
            o.asdf = d['asdf']
        if 'sadf' in d:
            o.sadf = d['sadf']
        if 'yuyu' in d:
            o.yuyu = d['yuyu']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenPromoPrizeDimension(object):

    def __init__(self):
        self._dimension = None
        self._values = None

    @property
    def dimension(self):
        return self._dimension

    @dimension.setter
    def dimension(self, value):
        self._dimension = value
    @property
    def values(self):
        return self._values

    @values.setter
    def values(self, value):
        if isinstance(value, list):
            self._values = list()
            for i in value:
                self._values.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.dimension:
            if hasattr(self.dimension, 'to_alipay_dict'):
                params['dimension'] = self.dimension.to_alipay_dict()
            else:
                params['dimension'] = self.dimension
        if self.values:
            if isinstance(self.values, list):
                for i in range(0, len(self.values)):
                    element = self.values[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.values[i] = element.to_alipay_dict()
            if hasattr(self.values, 'to_alipay_dict'):
                params['values'] = self.values.to_alipay_dict()
            else:
                params['values'] = self.values
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenPromoPrizeDimension()
        if 'dimension' in d:
            o.dimension = d['dimension']
        if 'values' in d:
            o.values = d['values']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Informant import Informant
from alipay.aop.api.domain.Injured import Injured
from alipay.aop.api.domain.Insured import Insured
from alipay.aop.api.domain.ReportCar import ReportCar
from alipay.aop.api.domain.ReportCar import ReportCar


class AlipayInsDataAutoFraudQueryModel(object):

    def __init__(self):
        self._accident_city = None
        self._accident_date = None
        self._accident_location = None
        self._case_amount = None
        self._estimate_damage_amount = None
        self._informant = None
        self._injured_count = None
        self._injured_list = None
        self._insure_city = None
        self._insured = None
        self._policy_no = None
        self._report_date = None
        self._report_no = None
        self._request_no = None
        self._scene_type = None
        self._subject_car = None
        self._third_party_car_count = None
        self._third_party_car_list = None

    @property
    def accident_city(self):
        return self._accident_city

    @accident_city.setter
    def accident_city(self, value):
        self._accident_city = value
    @property
    def accident_date(self):
        return self._accident_date

    @accident_date.setter
    def accident_date(self, value):
        self._accident_date = value
    @property
    def accident_location(self):
        return self._accident_location

    @accident_location.setter
    def accident_location(self, value):
        self._accident_location = value
    @property
    def case_amount(self):
        return self._case_amount

    @case_amount.setter
    def case_amount(self, value):
        self._case_amount = value
    @property
    def estimate_damage_amount(self):
        return self._estimate_damage_amount

    @estimate_damage_amount.setter
    def estimate_damage_amount(self, value):
        self._estimate_damage_amount = value
    @property
    def informant(self):
        return self._informant

    @informant.setter
    def informant(self, value):
        if isinstance(value, Informant):
            self._informant = value
        else:
            self._informant = Informant.from_alipay_dict(value)
    @property
    def injured_count(self):
        return self._injured_count

    @injured_count.setter
    def injured_count(self, value):
        self._injured_count = value
    @property
    def injured_list(self):
        return self._injured_list

    @injured_list.setter
    def injured_list(self, value):
        if isinstance(value, list):
            self._injured_list = list()
            for i in value:
                if isinstance(i, Injured):
                    self._injured_list.append(i)
                else:
                    self._injured_list.append(Injured.from_alipay_dict(i))
    @property
    def insure_city(self):
        return self._insure_city

    @insure_city.setter
    def insure_city(self, value):
        self._insure_city = value
    @property
    def insured(self):
        return self._insured

    @insured.setter
    def insured(self, value):
        if isinstance(value, Insured):
            self._insured = value
        else:
            self._insured = Insured.from_alipay_dict(value)
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def report_no(self):
        return self._report_no

    @report_no.setter
    def report_no(self, value):
        self._report_no = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value
    @property
    def subject_car(self):
        return self._subject_car

    @subject_car.setter
    def subject_car(self, value):
        if isinstance(value, ReportCar):
            self._subject_car = value
        else:
            self._subject_car = ReportCar.from_alipay_dict(value)
    @property
    def third_party_car_count(self):
        return self._third_party_car_count

    @third_party_car_count.setter
    def third_party_car_count(self, value):
        self._third_party_car_count = value
    @property
    def third_party_car_list(self):
        return self._third_party_car_list

    @third_party_car_list.setter
    def third_party_car_list(self, value):
        if isinstance(value, list):
            self._third_party_car_list = list()
            for i in value:
                if isinstance(i, ReportCar):
                    self._third_party_car_list.append(i)
                else:
                    self._third_party_car_list.append(ReportCar.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.accident_city:
            if hasattr(self.accident_city, 'to_alipay_dict'):
                params['accident_city'] = self.accident_city.to_alipay_dict()
            else:
                params['accident_city'] = self.accident_city
        if self.accident_date:
            if hasattr(self.accident_date, 'to_alipay_dict'):
                params['accident_date'] = self.accident_date.to_alipay_dict()
            else:
                params['accident_date'] = self.accident_date
        if self.accident_location:
            if hasattr(self.accident_location, 'to_alipay_dict'):
                params['accident_location'] = self.accident_location.to_alipay_dict()
            else:
                params['accident_location'] = self.accident_location
        if self.case_amount:
            if hasattr(self.case_amount, 'to_alipay_dict'):
                params['case_amount'] = self.case_amount.to_alipay_dict()
            else:
                params['case_amount'] = self.case_amount
        if self.estimate_damage_amount:
            if hasattr(self.estimate_damage_amount, 'to_alipay_dict'):
                params['estimate_damage_amount'] = self.estimate_damage_amount.to_alipay_dict()
            else:
                params['estimate_damage_amount'] = self.estimate_damage_amount
        if self.informant:
            if hasattr(self.informant, 'to_alipay_dict'):
                params['informant'] = self.informant.to_alipay_dict()
            else:
                params['informant'] = self.informant
        if self.injured_count:
            if hasattr(self.injured_count, 'to_alipay_dict'):
                params['injured_count'] = self.injured_count.to_alipay_dict()
            else:
                params['injured_count'] = self.injured_count
        if self.injured_list:
            if isinstance(self.injured_list, list):
                for i in range(0, len(self.injured_list)):
                    element = self.injured_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.injured_list[i] = element.to_alipay_dict()
            if hasattr(self.injured_list, 'to_alipay_dict'):
                params['injured_list'] = self.injured_list.to_alipay_dict()
            else:
                params['injured_list'] = self.injured_list
        if self.insure_city:
            if hasattr(self.insure_city, 'to_alipay_dict'):
                params['insure_city'] = self.insure_city.to_alipay_dict()
            else:
                params['insure_city'] = self.insure_city
        if self.insured:
            if hasattr(self.insured, 'to_alipay_dict'):
                params['insured'] = self.insured.to_alipay_dict()
            else:
                params['insured'] = self.insured
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.report_no:
            if hasattr(self.report_no, 'to_alipay_dict'):
                params['report_no'] = self.report_no.to_alipay_dict()
            else:
                params['report_no'] = self.report_no
        if self.request_no:
            if hasattr(self.request_no, 'to_alipay_dict'):
                params['request_no'] = self.request_no.to_alipay_dict()
            else:
                params['request_no'] = self.request_no
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        if self.subject_car:
            if hasattr(self.subject_car, 'to_alipay_dict'):
                params['subject_car'] = self.subject_car.to_alipay_dict()
            else:
                params['subject_car'] = self.subject_car
        if self.third_party_car_count:
            if hasattr(self.third_party_car_count, 'to_alipay_dict'):
                params['third_party_car_count'] = self.third_party_car_count.to_alipay_dict()
            else:
                params['third_party_car_count'] = self.third_party_car_count
        if self.third_party_car_list:
            if isinstance(self.third_party_car_list, list):
                for i in range(0, len(self.third_party_car_list)):
                    element = self.third_party_car_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.third_party_car_list[i] = element.to_alipay_dict()
            if hasattr(self.third_party_car_list, 'to_alipay_dict'):
                params['third_party_car_list'] = self.third_party_car_list.to_alipay_dict()
            else:
                params['third_party_car_list'] = self.third_party_car_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsDataAutoFraudQueryModel()
        if 'accident_city' in d:
            o.accident_city = d['accident_city']
        if 'accident_date' in d:
            o.accident_date = d['accident_date']
        if 'accident_location' in d:
            o.accident_location = d['accident_location']
        if 'case_amount' in d:
            o.case_amount = d['case_amount']
        if 'estimate_damage_amount' in d:
            o.estimate_damage_amount = d['estimate_damage_amount']
        if 'informant' in d:
            o.informant = d['informant']
        if 'injured_count' in d:
            o.injured_count = d['injured_count']
        if 'injured_list' in d:
            o.injured_list = d['injured_list']
        if 'insure_city' in d:
            o.insure_city = d['insure_city']
        if 'insured' in d:
            o.insured = d['insured']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'report_no' in d:
            o.report_no = d['report_no']
        if 'request_no' in d:
            o.request_no = d['request_no']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        if 'subject_car' in d:
            o.subject_car = d['subject_car']
        if 'third_party_car_count' in d:
            o.third_party_car_count = d['third_party_car_count']
        if 'third_party_car_list' in d:
            o.third_party_car_list = d['third_party_car_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItemExchangeInfo import ItemExchangeInfo


class AlipayCommerceOperationPromoterExchangeConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationPromoterExchangeConfirmResponse, self).__init__()
        self._item_exchange_info = None

    @property
    def item_exchange_info(self):
        return self._item_exchange_info

    @item_exchange_info.setter
    def item_exchange_info(self, value):
        if isinstance(value, ItemExchangeInfo):
            self._item_exchange_info = value
        else:
            self._item_exchange_info = ItemExchangeInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationPromoterExchangeConfirmResponse, self).parse_response_content(response_content)
        if 'item_exchange_info' in response:
            self.item_exchange_info = response['item_exchange_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CertificationForm import CertificationForm
from alipay.aop.api.domain.ParticipantPartyForm import ParticipantPartyForm


class AlipayFundAllocTransferModel(object):

    def __init__(self):
        self._agreement_no = None
        self._amount = None
        self._biz_scene = None
        self._certification = None
        self._order_title = None
        self._out_biz_no = None
        self._payee = None
        self._product_code = None
        self._remark = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def certification(self):
        return self._certification

    @certification.setter
    def certification(self, value):
        if isinstance(value, CertificationForm):
            self._certification = value
        else:
            self._certification = CertificationForm.from_alipay_dict(value)
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payee(self):
        return self._payee

    @payee.setter
    def payee(self, value):
        if isinstance(value, ParticipantPartyForm):
            self._payee = value
        else:
            self._payee = ParticipantPartyForm.from_alipay_dict(value)
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.certification:
            if hasattr(self.certification, 'to_alipay_dict'):
                params['certification'] = self.certification.to_alipay_dict()
            else:
                params['certification'] = self.certification
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payee:
            if hasattr(self.payee, 'to_alipay_dict'):
                params['payee'] = self.payee.to_alipay_dict()
            else:
                params['payee'] = self.payee
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundAllocTransferModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'certification' in d:
            o.certification = d['certification']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payee' in d:
            o.payee = d['payee']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'remark' in d:
            o.remark = d['remark']
        return o


